@@ -46,7 +46,7 @@ our %STRCACHE;
 
 This function binds on the given host and service port and returns a
 shell object, which determines the lifetime of the shell. Any number
-of conenctions are accepted on the port, and they will give you a very
+of connections are accepted on the port, and they will give you a very
 primitive shell that simply executes every line you enter.
 
 All commands will be executed "blockingly" with the socket C<select>ed for
@@ -122,7 +122,7 @@ sub shell($$) {
 
          $logger_guard if 0; # reference it
 
-         if (defined $len ? $len == 0 : $! != Errno::EAGAIN) {
+         if (defined $len ? $len == 0 : ($! != Errno::EAGAIN && $! != Errno::EWOULDBLOCK)) {
             undef $rw;
          } else {
             while ($rbuf =~ s/^(.*)\015?\012//) {
@@ -132,6 +132,27 @@ sub shell($$) {
 
                if ($line =~ /^\s*exit\b/) {
                   syswrite $fh, "sorry, no... if you want to execute exit, try CORE::exit.\015\012";
+               } elsif ($line =~ /^\s*coro\b\s*(.*)/) {
+                  my $arg = $1;
+                  if (eval { require Coro; require Coro::Debug }) {
+                     if ($arg =~ /\S/) {
+                        Coro::async (sub {
+                           select $fh;
+                           Coro::Debug::command ($arg);
+                           local $| = 1; # older Coro versions do not flush
+                           syswrite $fh, "> ";
+                        });
+                        return;
+                     } else {
+                        undef $rw;
+                        syswrite $fh, "switching to Coro::Debug...\015\012";
+                        Coro::async (sub { Coro::Debug::session ($fh) });
+                        return;
+                     }
+                  } else {
+                     syswrite $fh, "Coro not available.\015\012";
+                  }
+
                } else {
                   package AnyEvent::Debug::shell;
 
@@ -178,6 +199,8 @@ ut           disable tracing for newly created watchers
 t  id,...    enable tracing for the given watcher (enabled by default)
 ut id,...    disable tracing for the given watcher
 w id,...     converts the watcher ids to watcher objects (for scripting)
+coro xxx     run xxx as Coro::Debug shell command, if available
+coro         switch to Coro::Debug shell, if available
 EOF
    }
 
@@ -623,7 +646,7 @@ sub verbose {
 
    my $res = "type:    $self->{type} watcher\n"
            . "args:    " . (join " ", %{ $self->{arg} }) . "\n" # TODO: decode fh?
-           . "created: " . (AnyEvent::Log::ft $self->{now}) . " ($self->{now})\n"
+           . "created: " . (AnyEvent::Log::format_time $self->{now}) . " ($self->{now})\n"
            . "file:    ${ $self->{rfile} }\n"
            . "line:    $self->{line}\n"
            . "subname: $self->{sub}\n"
@@ -639,7 +662,7 @@ sub verbose {
    if (exists $self->{error}) {
       $res .= "errors:   " . @{$self->{error}} . "\n";
 
-      $res .= "error: " . (AnyEvent::Log::ft $_->[0]) . " ($_->[0]) $_->[1]\n"
+      $res .= "error: " . (AnyEvent::Log::format_time $_->[0]) . " ($_->[0]) $_->[1]\n"
          for @{$self->{error}};
    }
 
